@@ -4,8 +4,9 @@ New project initilizer
 import shutil
 import os
 from pathlib import Path
+from typing import Optional
 
-def new_project(cwd: str, name: str = None) -> None:
+def new_project(cwd: str, name: Optional[str] = None) -> None:
     if name is None:
         name = input("Project name: ")
     templates_path: Path = Path(os.path.join(os.path.dirname(__file__), "templates", "new_project"))
@@ -20,4 +21,3 @@ def new_project(cwd: str, name: str = None) -> None:
             shutil.copytree(item, target, dirs_exist_ok=True)
         else:
             shutil.copy2(item, target)
-
