@@ -7,6 +7,7 @@ import inspect
 import argparse
 import json
 import asyncio
+from enum import StrEnum
 from typing import Any, Callable, Mapping, Optional, Type, TypeVar, cast
 import aiofiles
 from loguru import logger
@@ -23,6 +24,7 @@ from jinja2 import (
 
 from .exceptions.http_exceptions import HtmlAborterException
 from .http_statuses import HttpStatus
+from .http_methods import HttpMethod
 from .request import Request
 from .response import Response
 from .utilities import get_app_root_path, run_sync_or_async, import_module
@@ -118,6 +120,10 @@ def on_shutdown(func) -> Callable:
     setattr(func, "_on_shutdown_method", True)
     return func
 
+class ScopeType(StrEnum):
+    LIFESPAN = "lifespan"
+    HTTP = "http"
+    WEBSOCKET = "websocket"
 
 class MissingAppConfigurations(Exception):
     def __init__(
@@ -206,6 +212,7 @@ class PyJolt:
         self._logger_sink_ids.append(sink_id)
 
         self._router = Router(self.get_conf("STRICT_SLASHES", False))
+        self._socket_router = Router(self.get_conf("STRICT_SLASHES", False))
         self._logger = logger
 
         self._app: AppCallableType = self._base_app
@@ -567,10 +574,10 @@ class PyJolt:
         if self.get_conf("OPEN_API", False):
             self.build_openapi_spec()
             self.register_openapi_controller()
-        app: AppCallableType = self._base_app
+        built_app: AppCallableType = self._base_app
         for factory in reversed(self._middleware):
-            app = factory(self, app)
-        self._app = app
+            built_app = factory(self, built_app)
+        self._app = built_app
         self._is_built = True
 
     def add_extension(self, extension):
@@ -596,7 +603,10 @@ class PyJolt:
         Raises DuplicateRoutePath if a route with the same (method, path) is already registered.
         """
         try:
-            self.router.add_route(url_path, func, [method], endpoint_name)
+            if method == HttpMethod.SOCKET.value:
+                self._socket_router.add_route(url_path, func, [method], endpoint_name)
+            else:
+                self.router.add_route(url_path, func, [method], endpoint_name)
         except Exception as e:
             # Detect more specific errors?
             raise e
@@ -604,6 +614,9 @@ class PyJolt:
     def register_controller(self, *ctrls: "type[Controller]"):
         """Registers controller class with application"""
         for ctrl in ctrls:
+            dev_only: bool = getattr(ctrl, "_development", False)
+            if dev_only and not self.get_conf("DEBUG", False):
+                continue
             ctrl_path: str = getattr(ctrl, "_controller_path")
             ctrl_open_api_spec = getattr(ctrl, "_include_open_api_spec")
             ctrl_open_api_tags = getattr(ctrl, "_open_api_tags", None)
@@ -703,7 +716,8 @@ class PyJolt:
             #pylint: disable-next=W0212
             func_kwargs = {name: value for name, value in args._get_kwargs()
                            if name not in ["command", "func"]}
-            asyncio.run(args.func(*func_args, **func_kwargs))  # pass the parsed arguments object
+            asyncio.run(run_sync_or_async(args.func, *func_args, **func_kwargs))
+            #asyncio.run(args.func(*func_args, **func_kwargs))  # pass the parsed arguments object
         else:
             self.cli.print_help()
 
@@ -780,11 +794,35 @@ class PyJolt:
         """
         if not self._is_built:
             self.build()
-        if scope["type"] == "lifespan":
+        if scope["type"] == ScopeType.LIFESPAN.value:
             return await self._lifespan_app(scope, receive, send)
-        if scope["type"] == "http":
+        if scope["type"] == ScopeType.HTTP.value:
             return await self._handle_http_request(scope, receive, send)
+        if scope["type"] == ScopeType.WEBSOCKET.value:
+            return await self._handle_websocket_request(scope, receive, send)
         raise ValueError(f"Unsupported scope type {scope['type']}")
+    
+    async def _handle_websocket_request(self, scope, receive, send):
+        """
+        Handles websocket requests
+        """
+        method: str = "SOCKET"
+        url_path: str = scope["path"]
+        self._log_request(scope, method, url_path)
+
+        route_handler, path_kwargs = self._socket_router.match(url_path, method)
+        if not route_handler:
+            await send({"type": "websocket.close","code": 1000})
+            return
+        req = Request(scope, receive, self, path_kwargs, cast(Callable, route_handler))
+        req.set_send(send)
+        try:
+            await run_sync_or_async(route_handler, req, **path_kwargs)
+        # pylint: disable-next=W0718
+        except Exception as exc:
+            await send({"type": "websocket.close", "code": 1011, "reason": "Internal server error"})
+            self.logger.critical(f"Unhandled critical error in websocket: ({req.method}) {req.path}, {req.route_parameters}: {exc}")
+            raise exc
 
     # ───────────────────────── CORS utilities ─────────────────────────
 
